lidarwind.data\_operator.ReadProcessedData
==========================================

.. currentmodule:: lidarwind.data_operator

.. autoclass:: ReadProcessedData

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~ReadProcessedData.__init__
      ~ReadProcessedData.merge_data
      ~ReadProcessedData.merge_data_method_1
      ~ReadProcessedData.merge_data_method_2
   
   

   
   
   